@@ -10,12 +10,12 @@ use itertools::Itertools;
 use k8s_openapi::apimachinery;
 use k8s_openapi::ByteString;
 use kube::api;
-use kube::config;
 use kube::{Resource, ResourceExt};
 use serde::{de, ser};
 
 use super::*;
 
+#[cfg(feature = "capi")]
 mod capi;
 mod helper;
 
@@ -69,13 +69,6 @@ impl Kubectl {
         Ok(text)
     }
 
-    pub async fn load_config_from_secret(&self, cluster: &str) -> kube::Result<kube::Config> {
-        let text = self.capi_kubeconfig(cluster).await?;
-        load_config_from_text(&text)
-            .await
-            .map_err(from_kubeconfig_error)
-    }
-
     pub async fn ensure_global_k_is_installed<K>(&self, object: K) -> kube::Result<K>
     where
         K: kube::ResourceExt + ser::Serialize + de::DeserializeOwned + Clone + fmt::Debug,
@@ -185,24 +178,3 @@ impl fmt::Debug for Kubectl {
             .finish()
     }
 }
-
-async fn load_config_from_text(text: &str) -> Result<config::Config, config::KubeconfigError> {
-    let kubeconfig = config::Kubeconfig::from_yaml(text)?;
-    let options = kube::config::KubeConfigOptions::default();
-    config::Config::from_custom_kubeconfig(kubeconfig, &options).await
-}
-
-fn from_kubeconfig_error(err: config::KubeconfigError) -> kube::Error {
-    // This is a workaround until the real error code will be possible to create
-    // let infer = config::InferConfigError {
-    //     in_cluster: config::InClusterError::MissingEnvironmentVariables, // Dummy error
-    //     kubeconfig: err,
-    // };
-    // kube::Error::InferConfig(infer)
-    log::warn!(
-        "Replacing {} with Error::LinesCodecMaxLineLengthExceeded",
-        err
-    );
-
-    kube::Error::LinesCodecMaxLineLengthExceeded
-}
